;; Generated package description from caps-lock.el  -*- no-byte-compile: t -*-
(define-package "caps-lock" "1.0.0.20201201.152011" "Caps-lock as a minor mode" 'nil :url "https://elpa.gnu.org/packages/caps-lock.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
